@@ -667,13 +667,13 @@ PREDICATE(hostname2, 1)
 
 // The eq_int64/2 and lt_int64/2 predicates test the deprecated PlTerm::operator==()
 
-#ifdef _MSC_VER
-#pragma warning( push )
-#pragma warning (disable:4996)
-#else
+// #ifdef _MSC_VER
+// #pragma warning( push )
+// #pragma warning (disable:4996)
+// #else
 // #pragma GCC diagnostic push
 // #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#endif
+// #endif
 
 // PREDICATE(eq_int64, 2)
 // { return A1 == A2.as_int64_t();
@@ -683,11 +683,11 @@ PREDICATE(hostname2, 1)
 // { return A1 < A2.as_int64_t();
 // }
 
-#ifdef _MSC_VER
-#pragma warning( pop )
-#else
+// #ifdef _MSC_VER
+// #pragma warning( pop )
+// #else
 // #pragma GCC diagnostic pop
-#endif
+// #endif
 
 PREDICATE(get_atom_ex, 2)
 { PlAtom a(PlAtom::null);
@@ -2141,9 +2141,10 @@ NAMED_PREDICATE("#", hash, 2)
 }
 
 PREDICATE(malloc_free, 2)
-{ // For verifying that example code of unique_ptr with PLfree() compiles
+{ // For verifying that example code of unique_ptr with PL_free() compiles
   std::unique_ptr<void, decltype(&PL_free)> ptr(PL_malloc(100), &PL_free);
 
+  PlStringBuffers _string_buffers;
   size_t len;
   char *str = nullptr;
   int rc = Plx_get_nchars(A1.unwrap(), &len, &str, BUF_MALLOC|CVT_ALL|CVT_WRITEQ|CVT_VARIABLE|REP_UTF8|CVT_EXCEPTION);
