@@ -243,7 +243,8 @@ typedef struct io_stream
   void *		exception;	/* pending exception (record_t) */
   void *		context;	/* getStreamContext() */
   struct PL_locale *	locale;		/* Locale associated to stream */
-  intptr_t		reserved[4];	/* reserved for extension */
+  intptr_t		fileno;		/* File number if this is associated to a file */
+  intptr_t		reserved[3];	/* reserved for extension */
 } IOSTREAM;
 
 
@@ -282,6 +283,8 @@ typedef struct io_stream
 #define SIO_BOM		SmakeFlag(31)	/* BOM was detected/written */
 #define SIO_REPPLU	SmakeFlag(32)	/* Bad char --> Prolog \uXXXX */
 
+#define SIO_TRYLOCK	SIO_CLOSING     /* Used by PL_get_stream() */
+
 #define	SIO_SEEK_SET	0	/* From beginning of file.  */
 #define	SIO_SEEK_CUR	1	/* From current position.  */
 #define	SIO_SEEK_END	2	/* From end of file.  */
@@ -443,8 +446,8 @@ PL_EXPORT(int)		Ssetlocale(IOSTREAM *s,
 				   struct PL_locale **old_loc);
 PL_EXPORT(int)		Sflush(IOSTREAM *s);
 PL_EXPORT(int64_t)	Ssize(IOSTREAM *s);
-PL_EXPORT(int)		Sseek(IOSTREAM *s, long pos, int whence);
-PL_EXPORT(long)		Stell(IOSTREAM *s);
+PL_EXPORT(int)		Sseek(IOSTREAM *s, long pos, int whence); /* WDEPRECATED */ /* use Sseek64() */
+PL_EXPORT(long)		Stell(IOSTREAM *s); /* WDEPRECATED */ /* use Stell64() */
 PL_EXPORT(int)		Sclose(IOSTREAM *s);
 PL_EXPORT(int)		Sgcclose(IOSTREAM *s, int flags);
 PL_EXPORT(char *)	Sfgets(char *buf, int n, IOSTREAM *s);
