@@ -200,7 +200,7 @@ static void
 rehashFunctors(void)
 { FunctorTable newtab;
   size_t index;
-  int i, last = FALSE;
+  int i, last = false;
 
   if ( functorDefTable->buckets * 2 >= GD->statistics.functors )
     return;
@@ -215,7 +215,7 @@ rehashFunctors(void)
 	Sdprintf("Rehashing functor-table (%d --> %d)\n",
 		 functorDefTable->buckets, newtab->buckets));
 
-  GD->functors.rehashing = TRUE;
+  GD->functors.rehashing = true;
   for(index=1, i=0; !last; i++)
   { size_t upto = (size_t)2<<i;
     FunctorDef *b;
@@ -225,7 +225,7 @@ rehashFunctors(void)
 
       if ( upto >= high )
       { upto = high;
-	last = TRUE;
+	last = true;
       }
 
       for(; index<upto; index++)
@@ -242,7 +242,7 @@ rehashFunctors(void)
   }
 
   functorDefTable = newtab;
-  GD->functors.rehashing = FALSE;
+  GD->functors.rehashing = false;
   maybe_free_functor_tables();
 }
 
@@ -465,7 +465,7 @@ pl_current_functor(term_t name, term_t arity, control_t h)
 { GET_LD
   atom_t nm = 0;
   size_t index;
-  int i, last=FALSE;
+  int i, last=false;
   int  ar;
   fid_t fid;
 
@@ -473,7 +473,7 @@ pl_current_functor(term_t name, term_t arity, control_t h)
   { case FRG_FIRST_CALL:
       if ( PL_get_atom(name, &nm) &&
 	   PL_get_integer(arity, &ar) )
-	return isCurrentFunctor(nm, ar) ? TRUE : FALSE;
+	return isCurrentFunctor(nm, ar) ? true : false;
 
       if ( !(PL_is_integer(arity) || PL_is_variable(arity)) )
 	return PL_error("current_functor", 2, NULL, ERR_TYPE,
@@ -502,7 +502,7 @@ pl_current_functor(term_t name, term_t arity, control_t h)
 
     if ( upto >= high )
     { upto = high;
-      last = TRUE;
+      last = true;
     }
 
     for(; index<upto; index++)
@@ -522,7 +522,7 @@ pl_current_functor(term_t name, term_t arity, control_t h)
   }
 
   PL_UNLOCK(L_FUNCTOR);
-  return FALSE;
+  return false;
 }
 
 
