@@ -211,12 +211,24 @@ test_that("matrices are properly translated",
   expect_identical(q$X, m)
 })
 
-test_that("check_installation works",
-{
-  query(call("check_installation"))
-  q <- submit()
-  clear()
-
-  # A few warnings will be displayed, that is fine.
-  expect_equal(q, list())
-})
+# For the future (currently memory leaking)
+#
+# test_that("check_installation works",
+# {
+#   query(call("check_installation"))
+#   q <- submit()
+#   clear()
+# 
+#   # A few warnings will be displayed, that is fine.
+#   expect_equal(q, list())
+# })
+#
+# test_that("test_installation works",
+# {
+#   query(call("test_installation", 
+#     list(call(arguments(list("-e", "rswipl:::swipl()", "-q", "--no-echo", "--args"))))
+#   q <- submit()
+#   clear()
+#
+#   expect_equal(q, list())
+# })
